package org.acme.security.jdbc;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class JdbcSecurityRealmTestIT extends JdbcSecurityRealmTest {
}
